FileService class

Constructors

FileService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

appendFile(String path, String content) → void
copyFile(String sourcePath, String destinationPath) → void
ensureDirectory(String path) → void
fileExists(String path) bool
readFile(String path) String
writeFile(String path, String content) → void