Decision class
Constructors
Properties
-
alternatives
→ List<
String> -
final
- choice → String?
-
final
- createdAt → DateTime
-
final
- description → String?
-
final
- detailFile → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- reason → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Convert Decision to YAML-compatible Map
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited