Feature class

Constructors

Feature({required String id, required String title, required String status, required String description, required List<String> files, String? detailFile})
Feature.fromMap(Map map)
Create Feature from YAML-compatible Map
factory

Properties

description String
final
detailFile String?
final
files List<String>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Convert Feature to YAML-compatible Map
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited