ContextService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
ensureContextFilesExist(
) → void -
ensureDataFilesExist(
) → void - Ensure data directory and YAML files exist
-
ensureInitialized(
) → void -
getActiveContext(
{int hours = 24}) → ActiveContext - Get the current active context by analyzing recent file changes
-
getRecentProgress(
{int lines = 5}) → List< String> - Get recent progress updates from progress.md
-
isInitialized(
) → bool -
loadAllFeatures(
) → List< Feature> - Load all features — active and archived. Use for management commands.
-
loadDecisions(
) → List< Decision> - Load decisions from decisions.yaml
-
loadFeatures(
) → List< Feature> - Load only active features (todo + in-progress) from features.yaml.
-
saveDecisions(
List< Decision> decisions) → void - Save decisions to decisions.yaml
-
saveFeatures(
List< Feature> features) → void - Save features. Completed/done entries are automatically moved to the archive section so they don't inflate active-context loads.
Constants
- contextDir → const String
- dataDir → const String