ActiveContext class

Constructors

ActiveContext({String? featureTitle, List<String> relatedFiles = const [], List<String> recentChanges = const [], String? featureDescription, String? featureStatus})
ActiveContext.fromMap(Map<String, dynamic> map)
Create ActiveContext from map
factory

Properties

featureDescription String?
final
featureStatus String?
final
featureTitle String?
final
hashCode int
The hash code for this object.
no setterinherited
recentChanges List<String>
final
relatedFiles List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasActiveContext() bool
Check if there is an active context
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON-compatible map
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited